@@ -1,3 +1,5 @@
+from datetime import timedelta
+
 import click
 
 from ..decorators import loses_interactivity, require_bins, require_login
@@ -25,5 +27,5 @@ def ssh_session_with_key(
     """
     client = options.create_saml_client(resource)
     instance = host_to_instance(client, host)
-    ensure_ssh_key(client, instance, port)
+    ensure_ssh_key(client, instance, port, ttl=timedelta(minutes=1))
     start_tunnel(client, instance, port)
