@@ -3,13 +3,14 @@ from pathlib import Path
 import click
 
 from ..decorators import loses_interactivity, require_bins, require_login
+from ..helpers.global_options import GlobalOptions
+from ..helpers.options import resource_argument
 from ..saml_clients.aws_profile import AwsCredentialsPath
-from . import GlobalOptions
 from .sym import sym
 
 
 @sym.command(short_help="Write out AWS credentials")
-@click.argument("resource")
+@resource_argument
 @click.option(
     "--path",
     help="credentials file path",
@@ -23,4 +24,4 @@ from .sym import sym
 @require_login
 def write_creds(options: GlobalOptions, resource: str, path: str, profile: str) -> None:
     """Write AWS credentials to a profile"""
-    options.create_saml_client(resource).write_creds(path=path, profile=profile)
+    options.create_saml_client(resource).write_creds(path_str=path, profile=profile)
