@@ -61,7 +61,7 @@ def run_subprocess(
                 text=True,
             )
             outputs.append(result.stdout)
-            options.dprint(f"stdout: {result.stdout}")
+            options.dprint(result.stdout)
         if capture_output_:
             return outputs
 
@@ -89,7 +89,7 @@ def intercept_errors(
                 if not (quiet or quiet_):
                     sys.stderr.write(message)
                 else:
-                    options.dprint(f"error message: {message}")
+                    options.dprint(message)
                 if suppress or suppress_:
                     raise SuppressedError(err) from err
                 else:
