@@ -1,10 +1,13 @@
 import shlex
 from subprocess import CalledProcessError
-from typing import Mapping, Pattern, Type
+from typing import Mapping, Pattern, Type, Union
 
-from click import ClickException
+from click import BadParameter, ClickException, utils
+from click._compat import get_text_stderr
 from sentry_sdk import capture_exception
 
+from .helpers.envvar_option import get_used
+
 ErrorPatterns = Mapping[Pattern[str], Type[Exception]]
 
 
@@ -13,6 +16,22 @@ def raise_if_match(patterns: ErrorPatterns, msg: str):
         raise error
 
 
+def get_active_env_vars():
+    if used := get_used():
+        mapping = "\n".join([f"{k}\t--{n}={v}" for k, (n, v) in used.items()])
+        envvars = "\n".join(["Active Env Vars:", mapping])
+        return f"\n\n{envvars}"
+    else:
+        return ""
+
+
+def _format_message(self, file=None):
+    return f"{self.message}{get_active_env_vars()}"
+
+
+BadParameter.format_message = _format_message
+
+
 class CliErrorMeta(type):
     _exit_code_count = 1
 
@@ -33,6 +52,9 @@ class CliError(ClickException, metaclass=CliErrorMeta):
             capture_exception()
         super().show()
 
+    def format_message(self):
+        return _format_message(self)
+
 
 class CliErrorWithHint(CliError):
     def __init__(self, message, hint, **kwargs) -> None:
@@ -78,6 +100,11 @@ class InstanceNotFound(CliError):
         super().__init__(f"Could not find instance {instance}")
 
 
+class SAMLClientNotFound(CliError):
+    def __init__(self) -> None:
+        super().__init__("No valid SAML client found in PATH")
+
+
 class BotoError(CliErrorWithHint):
     def __init__(self, wrapped: "ClientError", hint: str) -> None:
         message = f"An AWS error occured!\n{str(wrapped)}"
@@ -85,8 +112,11 @@ class BotoError(CliErrorWithHint):
 
 
 class FailedSubprocessError(CliError):
-    def __init__(self, wrapped: CalledProcessError):
-        super().__init__(f"Cannot run {shlex.join(wrapped.cmd)}")
+    def __init__(self, wrapped: Union[CalledProcessError, str]):
+        if isinstance(wrapped, str):
+            super().__init__(wrapped)
+        else:
+            super().__init__(f"Cannot run {shlex.join(wrapped.cmd)}")
 
 
 class SuppressedError(FailedSubprocessError):
@@ -101,6 +131,7 @@ class SuppressedError(FailedSubprocessError):
 
 class WrappedSubprocessError(FailedSubprocessError):
     def __init__(self, wrapped, hint, **kwargs) -> None:
+        super().__init__(wrapped)
         messages = [
             f"Cannot run {wrapped.cmd[0]} [{wrapped.returncode}]",
             f"Hint: {hint}",
