@@ -1,4 +1,5 @@
 import re
+import time
 from functools import wraps
 from textwrap import dedent
 from typing import Optional
@@ -6,8 +7,9 @@ from typing import Optional
 import boto3
 import validators
 from botocore.config import Config as BotoConfig
-from botocore.exceptions import ClientError
+from botocore.exceptions import ClientError, WaiterError
 
+from ..decorators import retry
 from ..errors import (
     BotoError,
     CliError,
@@ -20,6 +22,7 @@ from .params import get_ssh_user
 
 InstanceIDPattern = re.compile("^i-[a-f0-9]+$")
 UnauthorizedError = re.compile(r"UnauthorizedOperation")
+RequestExpired = re.compile(r"RequestExpired")
 
 
 def intercept_boto_errors(f):
@@ -32,6 +35,12 @@ def intercept_boto_errors(f):
                 raise BotoError(
                     err, f"Does your user role have permission to {err.operation_name}?"
                 )
+            if RequestExpired.search(str(err)):
+                raise BotoError(
+                    err,
+                    f"Your AWS credentials have expired. Try running `sym write-creds` again.",
+                )
+
             raise CliError(str(err)) from err
 
     return wrapped
@@ -62,13 +71,33 @@ def send_ssh_key(saml_client: "SAMLClient", instance: str, ssh_key: SymConfigFil
         """
     ).strip()
     # fmt: on
-    ssm_client.send_command(
+
+    response = ssm_client.send_command(
         InstanceIds=[instance],
         DocumentName="AWS-RunShellScript",
         Comment="SSH Key for Sym",
         Parameters={"commands": command.splitlines()},
     )
 
+    saml_client.dprint(response)
+
+    _wait_for_command(ssm_client, instance, response)
+
+
+@retry(
+    WaiterError,
+    count=5,
+    delay=1,
+    check_ex=lambda ex: ex.last_response["Error"]["Code"] == "InvocationDoesNotExist",
+)
+def _wait_for_command(ssm_client, instance, response):
+    waiter = ssm_client.get_waiter("command_executed")
+    waiter.wait(
+        InstanceId=instance,
+        CommandId=response["Command"]["CommandId"],
+        WaiterConfig={"Delay": 1},
+    )
+
 
 @intercept_boto_errors
 def find_instance(saml_client, keys, value) -> Optional[str]:
@@ -85,6 +114,12 @@ def find_instance(saml_client, keys, value) -> Optional[str]:
                 return response["Reservations"][0]["Instances"][0]["InstanceId"]
 
 
+@intercept_boto_errors
+def get_identity(saml_client) -> dict:
+    sts_client = boto_client(saml_client, "sts")
+    return sts_client.get_caller_identity()
+
+
 def host_to_instance(saml_client, host: str) -> str:
     if InstanceIDPattern.match(host):
         target = host
