@@ -18,7 +18,7 @@ class GlobalOptions:
     log_dir: Optional[str] = None
 
     def dprint(self, s: str):
-        if self.debug:
+        if s and self.debug:
             print(f"{s}\n", file=sys.stderr)
 
     def create_saml_client(self, resource: str) -> "SAMLClient":
