@@ -1,10 +1,14 @@
-from typing import Any, Callable
+import logging
+from contextlib import ExitStack
+from typing import Any, Callable, ClassVar, List
 
 from click import Command, Context, Group
 from sentry_sdk.api import push_scope
 
+from ..errors import get_active_env_vars
 from ..saml_clients.chooser import choose_saml_client
 from . import segment
+from .tee import Tee, TeeStdErr, TeeStdOut
 
 
 class AutoTagCommand(Command):
@@ -14,9 +18,6 @@ class AutoTagCommand(Command):
     raised from the command are logged.
     """
 
-    def __init__(self, *args: Any, **attrs: Any) -> None:
-        super().__init__(*args, **attrs)
-
     def invoke(self, ctx: Context) -> Any:
         segment.track(
             "Command Executed", command=ctx.info_name, options=ctx.obj.to_dict()
@@ -41,6 +42,11 @@ class AutoTagCommand(Command):
             args = [resource] + args
         return super().parse_args(ctx, args)
 
+    def format_epilog(self, ctx, formatter):
+        if not self.epilog:
+            formatter.write(get_active_env_vars())
+        super().format_epilog(ctx, formatter)
+
 
 class SymGroup(Group):
     """
@@ -48,9 +54,28 @@ class SymGroup(Group):
     AutoTagCommand.
     """
 
+    tees: ClassVar[List[Tee]] = []
+
     def __init__(self, *args: Any, **attrs: Any) -> None:
         super().__init__(*args, **attrs)
 
+    def __del__(self):
+        for tee in self.__class__.tees:
+            tee.close()
+
+    def invoke(self, ctx: Context) -> Any:
+        if (log_dir := ctx.params.get("log_dir")) :
+            # Don't register exit handler so exceptions are teed.
+            # Instead, __del__ will be called when the program exits.
+            self.__class__.tees.extend((TeeStdOut(log_dir), TeeStdErr(log_dir)))
+
+            if ctx.params.get("debug"):
+                logging.basicConfig(
+                    level=logging.DEBUG, filename=Tee.path_for_fd(log_dir, "logging")
+                )
+
+        return super().invoke(ctx)
+
     def command(
         self, *args: Any, **kwargs: Any
     ) -> Callable[[Callable[..., Any]], AutoTagCommand]:
