@@ -10,11 +10,12 @@ from _pytest.monkeypatch import MonkeyPatch
 from botocore.stub import Stubber
 from click.testing import CliRunner
 
-from sym.cli.commands import GlobalOptions
+from sym.cli.helpers.global_options import GlobalOptions
 from sym.cli.helpers import boto
 from sym.cli.helpers.config import Config
-from sym.cli.saml_clients import SAMLClient
 from sym.cli.saml_clients.aws_okta import AwsOkta
+from sym.cli.saml_clients.aws_profile import AwsProfile
+from sym.cli.saml_clients.saml_client import SAMLClient
 from sym.cli.sym import sym as click_command
 from sym.cli.tests.helpers.capture import CaptureCommand
 from sym.cli.tests.helpers.sandbox import Sandbox
@@ -63,9 +64,11 @@ def capture_command(monkeypatch: MonkeyPatch) -> CaptureCommand:
 def click_context(sandbox):
     with sandbox.push_xdg_config_home():
         Config.instance()["org"] = "sym"
-        with click.Context(click_command) as ctx:
-            ctx.ensure_object(GlobalOptions)
-            yield ctx
+        sandbox.create_binary(f"bin/{AwsOkta.binary}")
+        with sandbox.push_exec_path():
+            with click.Context(click_command) as ctx:
+                ctx.ensure_object(GlobalOptions)
+                yield ctx
 
 
 @pytest.fixture
@@ -85,16 +88,48 @@ def click_setup(sandbox: Sandbox):
 
 
 @pytest.fixture
-def saml_client(sandbox):
+def saml_client(sandbox: Sandbox, monkeypatch: MonkeyPatch):
+    def get_creds(self):
+        return {
+            "AWS_REGION": "us-east-2",
+            "AWS_ACCESS_KEY_ID": "ASIA4GNNUMIHHBPSAQC3",
+            "AWS_SECRET_ACCESS_KEY": "xxx",
+            "AWS_SESSION_TOKEN": "xxx",
+        }
+
+    monkeypatch.setattr(AwsOkta, "get_creds", get_creds)
+
     sandbox.create_binary(f"bin/{AwsOkta.binary}")
-    return AwsOkta("test", debug=False)
+    with sandbox.push_exec_path():
+        return AwsOkta("test", options=GlobalOptions(debug=False))
 
 
 @pytest.fixture
 def boto_stub(monkeypatch: MonkeyPatch):
+    stubs = {}
+
     def boto_client(_saml_client, service):
-        client = boto3.resource(service).meta.client
-        Stubber(client).activate()
+        if service in stubs:
+            return stubs[service][0]
+
+        client = boto3.client(service)
+        stubber = Stubber(client)
+        stubber.activate()
+
+        stubs[service] = (client, stubber)
         return client
 
     monkeypatch.setattr(boto, "boto_client", boto_client)
+
+    def get_stub(service):
+        boto_client(None, service)
+        return stubs[service][1]
+
+    return get_stub
+
+
+@contextmanager
+def setup_context():
+    with click.Context(click_command) as ctx:
+        ctx.obj = GlobalOptions(saml_client_type=AwsProfile)
+        yield
