@@ -1,4 +1,5 @@
 import json
+from multiprocessing import Pool
 from uuid import UUID
 
 import pytest
@@ -45,3 +46,21 @@ def test_sym_config_truncate(sandbox: Sandbox):
         with config_file as f:
             assert f.read() == short_json
 
+
+def _exclusive_create_write_fn(args):
+    file_name, body = args
+    config_file = SymConfigFile(file_name=file_name)
+    with config_file.exclusive_create() as f:
+        f.write(body)
+
+
+def test_sym_config_exclusive_create_already_created(sandbox: Sandbox):
+    file_name = "config.json"
+    body = json.dumps({"hello": "world"})
+
+    with sandbox.push_xdg_config_home():
+        with Pool(processes=4) as pool:
+            pool.map(_exclusive_create_write_fn, [(file_name, body)] * 100)
+
+        with SymConfigFile(file_name=file_name) as f:
+            assert f.read() == body
