@@ -7,7 +7,7 @@ import click
 import pytest
 from _pytest.monkeypatch import MonkeyPatch
 
-from sym.cli.commands import GlobalOptions
+from sym.cli.helpers.global_options import GlobalOptions
 from sym.cli.helpers import boto
 from sym.cli.helpers.config import Config
 from sym.cli.helpers.contexts import push_env
@@ -29,9 +29,9 @@ def test_context(
     @contextmanager
     def context(*, debug: bool) -> Iterator[P]:
         with sandbox.push_xdg_config_home(), custom_org("launch-darkly"):
-            sandbox.create_file(f"bin/{constructor.binary}", 0o755)
+            sandbox.create_binary(f"bin/{constructor.binary}")
             with sandbox.push_exec_path():
-                yield constructor("catfood", debug=debug)
+                yield constructor("catfood", options=GlobalOptions(debug=debug))
 
     return context
 
@@ -58,10 +58,10 @@ def test_context_with_creds(
         with push_env("AWS_CREDENTIAL_FILE", str(path)):
             setattr(aws_profile, "AwsCredentialsPath", path)
             with sandbox.push_xdg_config_home(), custom_org("launch-darkly"):
-                sandbox.create_file(f"bin/{constructor.binary}", 0o755)
+                sandbox.create_binary(f"bin/{constructor.binary}")
                 sandbox.create_file(".aws/credentials", 0o755, creds)
                 with sandbox.push_exec_path():
-                    yield constructor("catfood", debug=debug)
+                    yield constructor("catfood", options=GlobalOptions(debug=debug))
 
     return context
 
@@ -77,7 +77,7 @@ def _subprocess_friendly_asserter(args: Tuple[Type[P], Sandbox]) -> None:
         Config.instance()["org"] = "sym"
         with click.Context(click_command) as ctx:
             ctx.ensure_object(GlobalOptions)
-            constructor("test", debug=False).exec("env")
+            constructor("test", options=GlobalOptions(debug=False)).exec("env")
             capture_command.assert_command(*expected_command)
 
 
@@ -85,5 +85,5 @@ def _subprocess_friendly_asserter(args: Tuple[Type[P], Sandbox]) -> None:
 def subprocess_friendly_asserter(constructor: Type[P]):
     with tempfile.TemporaryDirectory() as tmpdirname:
         sandbox = Sandbox(Path(tmpdirname))
-        sandbox.create_file(f"bin/{constructor.binary}", 0o755)
+        sandbox.create_binary(f"bin/{constructor.binary}")
         yield (_subprocess_friendly_asserter, constructor, sandbox)
